@@ -5,5 +5,5 @@
 
 from .polar import generate_2D_polar_grid
 from .polar import generate_2D_uniform_circular_sector
-from .pencil import generate_2D_pencil
+from .pencil import generate_2D_pencil, generate_2D_pencil_with_absolute_cut
 from .gaussian import generate_2D_gaussian
